<?xml version="1.0" encoding="utf-8"?>
<!--
/**
 * Templates shared by PRIDE and mzData XSLT files
 *
 * @author  Antony Quinn
 * @version $Id: common.xsl,v 1.8 2007/08/20 09:08:25 martlenn Exp $
 *
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <!-- Config XML (this can be passed in as a nodeset) -->
    <xsl:param name="config" select="document('config.xml')/config"/>
    
    <xsl:variable name="style.table"     select="$config/styles/style[@name='table']"/>
    
    <!-- Text properties -->
    <xsl:variable name="word.ellipse" select="$config/text/@ellipse"/>
    <xsl:variable name="word.wrap"    select="$config/text/@wrap"/>  

    <!-- Any node with cvParams and/or userParams -->
    <xsl:template match="node()" mode="params">
        <xsl:param name="style" select="'background-color: #dddddd;'"/>
        <xsl:choose>
            <xsl:when test="userParam or cvParam">
                <table cellpadding="1px" border="1" style="{$style.table}; {$style}">
                    <tr>
                        <th width="10%" class="smallbold">Source</th>
                        <th width="20%" class="smallbold">Name</th>
                        <th width="70%" class="smallbold">Value</th>
                    </tr>
                    <xsl:apply-templates />
                </table>
            </xsl:when>
            <xsl:otherwise>&#160;</xsl:otherwise>
        </xsl:choose>
    </xsl:template>    
    
    <!-- Composed of name, value -->
    <xsl:template match="userParam">
        <tr>
            <td width="10%" class="small">
                User
            </td>            
            <td width="20%" class="small">
                <xsl:apply-templates select="@name"/>
            </td>
            <td width="70%" class="small">
                <xsl:apply-templates select="@value"/>
            </td>            
        </tr>        
    </xsl:template>    

    <!-- Composed of @cvLabel, @accession, @name, @value -->
    <xsl:template match="cvParam">
        <tr>
            <td width="10%" class="small">
                <xsl:apply-templates select="@cvLabel"/>
            </td>            
            <td width="20%" class="small">
                <xsl:apply-templates select="." mode="link"/>
            </td>
            <td width="70%" class="small">
                <!--xsl:apply-templates select="@value"/-->
                <xsl:choose>
                    <xsl:when test="@cvLabel = 'PubMed' or @cvLabel = 'ISBN' or @cvLabel = 'ChEBI' or @cvLabel = 'IntAct'">
                        <xsl:value-of select="@name"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:apply-templates select="@value"/>                
                    </xsl:otherwise>
                </xsl:choose>
            </td>
        </tr>
    </xsl:template>
    
    <xsl:template match="cvParam" mode="link">
        <xsl:variable name="text">
            <xsl:choose>                
                <xsl:when test="@cvLabel = 'PubMed' or @cvLabel = 'ISBN' or @cvLabel = 'ChEBI' or @cvLabel = 'IntAct'">
                    <xsl:value-of select="@accession"/>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:apply-templates select="@name"/>                
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:variable name="href">
            <xsl:apply-templates select="current()" mode="href">
                <xsl:with-param name="database" select="@cvLabel"/>
                <xsl:with-param name="accession" select="@accession"/>
            </xsl:apply-templates>             
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="string-length($href) = 0">
                <xsl:value-of select="$text"/>
            </xsl:when>
            <xsl:otherwise>                
                <a class ="red_boldsmall" href="{$href}" title="{@name} ({@accession})">
                    <xsl:value-of select="$text"/>
                </a>                
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>
    
    <xsl:template match="cvParam/@cvLabel | userParam/@cvLabel">
        <xsl:value-of select="."/>
    </xsl:template>    
    
    <xsl:template match="cvParam/@name | userParam/@name">
        <xsl:choose>
            <xsl:when test="contains(., ' ') or string-length(.) &lt; $word.ellipse">
                <xsl:value-of select="."/>
            </xsl:when>
            <xsl:otherwise>
                <acronym title="{.}">
                    <xsl:value-of select="substring(., 1, $word.ellipse)"/>...
                </acronym>
            </xsl:otherwise>
        </xsl:choose>        
    </xsl:template>

    <xsl:template match="cvParam/@value | userParam/@value">        
        <xsl:choose>
            <xsl:when test="string-length(.) = 0">&#160;</xsl:when>
            <xsl:otherwise>
                <!--xsl:apply-templates select="." mode="textlink">
                    <xsl:if test="not(contains(., ' '))">
                        <xsl:with-param name="linktext">
                            <xsl:call-template name="split-string">
                                <xsl:with-param name="str" select="."/>    
                            </xsl:call-template>
                        </xsl:with-param>                 
                    </xsl:if>
                </xsl:apply-templates-->   
                <xsl:choose>
                    <xsl:when test="contains(., ' ')">
                        <xsl:apply-templates select="." mode="textlink"/>
                    </xsl:when>
                    <xsl:otherwise>                    
                        <xsl:apply-templates select="." mode="textlink">
                            <xsl:with-param name="split" select="'true'"/>
                        </xsl:apply-templates>
                    </xsl:otherwise>
                </xsl:choose>                 
            </xsl:otherwise>
        </xsl:choose>   
    </xsl:template>
    
    <xsl:template match="@* | node()" mode="textlink">
        <xsl:param name="split" select="'false'"/>
        <xsl:variable name="text">
            <xsl:choose>
                <xsl:when test="$split = 'true'">
                    <xsl:call-template name="split-string">
                        <xsl:with-param name="str" select="."/>
                    </xsl:call-template>
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="."/>
                </xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="starts-with(., 'http') or
                            starts-with(., 'ftp') or
                            starts-with(., 'mailto:')">
                <a href="{.}"><xsl:value-of select="$text"/></a>
            </xsl:when>
            <xsl:when test="contains(., '@') and contains(., '.')">
                <a href="mailto:{.}"><xsl:value-of select="$text"/></a>
            </xsl:when>            
            <xsl:otherwise>
                <xsl:value-of select="$text"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>      
    
    <!-- Build URL based on database name and accession number -->
    <xsl:template match="node()" mode="href">
        <xsl:param name="database"/>
        <xsl:param name="accession"/>
        <!-- Find URL entry in config.xml corresponding to start of $database -->
        <xsl:variable name="url" select="$config/urls/url[starts-with($database, @database)]"/>
        <xsl:if test="$url">
            <xsl:variable name="href" select="normalize-space($url/text())"/>
            <!-- Accession number version separator (eg. "." in IPI00187967.1) -->
            <xsl:variable name="version-sep" select="$config/urls/@version-separator"/>
            <xsl:variable name="id">
                <xsl:choose>
                    <xsl:when test="$url/@remove-version = 'true'
                                     and contains($accession, $version-sep)">
                        <!-- Remove version from accession -->
                        <xsl:value-of select="substring-before($accession, $version-sep)"/>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$accession"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:variable>
            <xsl:choose>
                <xsl:when test="$url/@accession = 'false'">
                    <!-- Do not append id to URL -->
                    <xsl:value-of select="$href"/>    
                </xsl:when>
                <xsl:otherwise>
                    <xsl:choose>
                        <xsl:when test="$url/@embedded = 'true'">
                            <!-- id is embedded in URL -->
                            <xsl:variable name="idvar" select="$config/urls/@idvar"/>
                            <xsl:value-of select="substring-before($id, $idvar)"/>
                            <xsl:value-of select="$id"/>
                            <xsl:value-of select="substring-after($id, $idvar)"/>
                        </xsl:when>
                        <xsl:otherwise>
                            <!-- Append id to URL -->
                            <xsl:value-of select="concat($href, $id)"/>    
                        </xsl:otherwise>
                    </xsl:choose>                
                </xsl:otherwise>
            </xsl:choose>
        </xsl:if>
    </xsl:template>
    
    <!-- Split long strings to allow text wrapping -->
    <xsl:template name="split-string">
        <xsl:param name="str"/>
        <xsl:param name="max" select="$word.wrap"/>
        <xsl:choose>                    
            <xsl:when test="string-length($str) > $max">
                <xsl:variable name="substr" select="substring($str, 1, $max)"/>
                <xsl:value-of select="substring($substr, 1, $max)"/>&#160;
                <xsl:variable name="subsubstr"
                              select="substring($str, number($max + 1), string-length($str))"/>
                <xsl:choose>
                    <xsl:when test="string-length($subsubstr) > $max">
                        <!-- Recursion -->
                        <xsl:call-template name="split-string">
                            <xsl:with-param name="str" select="$subsubstr"/>
                            <xsl:with-param name="max" select="$max"/>
                        </xsl:call-template>
                    </xsl:when>
                    <xsl:otherwise>
                        <xsl:value-of select="$subsubstr"/>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$str"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

</xsl:stylesheet>
