<?xml version="1.0" encoding="utf-8"?>
<!--
/**
 * Displays mzData XML as a set of HTML tables using EBI CSS rules.
 *
 * @author  Antony Quinn
 * @version $Id: mzdata.xsl,v 1.4 2007/01/03 18:43:32 martlenn Exp $
 * @note    The output from this stylesheet is included in another HTML page, so there are no HEAD or BODY sections.
-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:include href="common.xsl"/>

    <xsl:output method="html"
                encoding="iso-8859-1"
                indent="yes"
                media-type="text/html"
                standalone="yes"/>

    <!-- Config XML (this can be passed in as a nodeset) -->
    <!-- The config variable is defined in common.xsl so we don't need it here -->
    <!--xsl:param name="config" select="document('config.xml')/config"/-->

    <!-- Styles -->
    <xsl:variable name="style.header"    select="$config/styles/style[@name='header']"/>
    <xsl:variable name="style.subheader" select="$config/styles/style[@name='subheader']"/>
    <xsl:variable name="style.table.header" select="$config/styles/style[@name='table.header']"/>
    <xsl:variable name="style.table.th"  select="$config/styles/style[@name='table.th']"/>

    <xsl:template match="mzData">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th colspan="3" class="tablegreen" style="{$style.table.header}">
					<xsl:variable name="prideAcc" select="ancestor::Experiment/ExperimentAccession"/>
					<xsl:if test="$prideAcc">
						<a name="mzData{$prideAcc}"/>
					</xsl:if>
					mzData
                </th>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.header}">Information:</th>
                <td class="small_bold" colspan="2">
                    <table cellpadding="1px" border="1" style="{$style.table}">
                        <tr>
                            <th class="smallbold" style="{$style.table.th}">Version:</th>
                            <td class="small"><xsl:value-of select="@version"/></td>
                        </tr>
                        <tr>
                            <th class="smallbold" style="{$style.table.th}">Accession:</th>
                            <td class="small"><xsl:value-of select="@accessionNumber"/></td>
                        </tr>
                    </table>
                </td>
            </tr>
            <xsl:apply-templates select="description"/>
            <xsl:apply-templates select="spectrumList"/>
        </table>
    </xsl:template>

    <xsl:template match="description">
        <xsl:apply-templates select="admin"/>
        <tr>
            <th class="smallbold" style="{$style.header}">
			    <xsl:variable name="prideAcc" select="ancestor::Experiment/ExperimentAccession"/>
				<xsl:if test="$prideAcc">
					<a name="instrument{$prideAcc}"/>
				</xsl:if>
				Instrument:
			</th>
            <td class="small_bold" colspan="2">
                <xsl:apply-templates select="instrument"/>
            </td>
        </tr>
        <tr>
            <th rowspan="2 + {count(dataProcessing/processingMethod/node())}" class="smallbold" style="{$style.header}">
				<xsl:variable name="prideAcc" select="ancestor::Experiment/ExperimentAccession"/>
				<xsl:if test="$prideAcc">
					<a name="dataprocessing{$prideAcc}"/>
				</xsl:if>
				Data Processing:
            </th>
            <td class="small_bold" colspan="2">
                <xsl:apply-templates select="dataProcessing"/>
            </td>
        </tr>
        <tr>
            <td>
                <table cellpadding="1px" border="1" style="{$style.table}">
                    <tr>
                        <th class="smallbold" style="{$style.table.th}">Processing Method:</th>
                        <td class="small">
                            <xsl:apply-templates select="dataProcessing/processingMethod" mode="params"/>
                        </td>
                    </tr>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="spectrumList">
        <tr>
            <th colspan="3" style="{$style.subheader};color:#ffffff">
				<xsl:variable name="prideAcc" select="ancestor::Experiment/ExperimentAccession"/>
				<xsl:if test="$prideAcc">
					<a name="spectrumList{$prideAcc}"/>
				</xsl:if>
				Spectrum List<br/>
                <span class="small" style="color:#ffffff">
                    There are <xsl:value-of select="@count"/> spectra in this data set
                </span>
            </th>
        </tr>
        <xsl:apply-templates select="spectrum"/>
    </xsl:template>

    <xsl:template match="spectrum">
        <xsl:variable name="style"><xsl:if test="position() mod 2 = 0">background-color:#ffffff</xsl:if></xsl:variable>
        <tr style="{$style}">
            <td class="small" align="center">
                <a>
                    <xsl:attribute name="name"><xsl:apply-templates select="current()" mode="specref"/></xsl:attribute>
                </a>
                Spectrum ID: <xsl:value-of select="@id"/>
				<br/>
				<a href="#top" style="font-weight:bold;text-decoration:none;">
					(top <span style="font-size: 130%">&#8593;</span>)
				</a>
			</td>
            <td colspan="2" class="small">
                <table cellpadding="1px" border="1" style="{$style.table}">
                    <xsl:apply-templates select="spectrumDesc/spectrumSettings/acqSpecification"/>
                    <xsl:apply-templates select="spectrumDesc/spectrumSettings/spectrumInstrument"/>
                    <xsl:apply-templates select="spectrumDesc/precursorList"/>
                    <xsl:apply-templates select="spectrumDesc/comments"/>
                    <xsl:apply-templates select="current()" mode="view-spectrum"/>
                    <xsl:apply-templates select="supDesc"/>
                    <xsl:apply-templates select="supDataArrayBinary"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="node()" mode="specref">
        <xsl:param name="specid" select="@id"/>
        <!-- Note: Experiment is a PRIDE element, not an mzData element -->
        <xsl:variable name="acc" select="ancestor::Experiment/ExperimentAccession"/>
        <xsl:variable name="expid">
            <xsl:choose>
                <xsl:when test="$acc">e<xsl:value-of select="$acc"/></xsl:when>
                <xsl:otherwise></xsl:otherwise>
            </xsl:choose>
        </xsl:variable>
        <xsl:value-of select="concat($expid, 's', $specid)"/>
    </xsl:template>

    <xsl:template match="spectrum" mode="view-spectrum">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Spectrum</th>
            <!-- TODO: make this indepenent of PRIDE for PSI.
                 Config.xml: add a switch to control how works.
                 I also thought about the problem of Javascript pop ups
                 (they're blocked by default in Firefox). I will think about the
                 alternative config-controlled option for PSI - one thought is
                 to pass the encoded arrays to a static HTML file as URL
                 parameters and then parse the parameters client-side using
                 Javascript (I've done this before). We would then get round
                 the pop-up problem by having a link such as:
                 <a href="spectrum.html?acc=1&spec=2&mz=UjBsR&inten=1GUXhEUzhi" target="_blank">
            -->
            <td class="small">
                <a title="{mzArrayBinary/data/@endian} endian: {mzArrayBinary/data}"
                   href="viewSpectrum.do?mzDataAccession={../../@accessionNumber}&amp;spectrumReference={@id}"
                   target="_blank"
                   class="red_boldsmall">
                    View spectrum
                </a>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="acqSpecification">
        <tr>
            <th class="smallbold" style="{$style.table.th}">
                Acquisition<br/>
                (count: <xsl:value-of select="@count"/>)
            </th>
            <td class="small">
                <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
                     <tr>
                         <th colspan="2" class="smallbold">Acquisition Parameters</th>
                     </tr>
                     <tr>
                         <td class="small">Spectrum Type</td>
                         <td class="small"><xsl:value-of select="@spectrumType"/></td>
                     </tr>
                     <tr>
                         <td class="small">Method of Combination</td>
                         <td class="small"><xsl:value-of select="@methodOfCombination"/></td>
                     </tr>
                     <xsl:apply-templates select="acquisition"/>
                 </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="acquisition">
        <tr>
            <th class="small" style="{$style.table.th}">Acquisition #<xsl:value-of select="@acqNumber"/></th>
            <td class="small">
                <xsl:apply-templates select="current()" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="spectrumInstrument">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Instrument Parameters</th>
            <td class="small">
                <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
                    <tr>
                        <th class="smallbold">Source</th>
                        <th class="smallbold">Name</th>
                        <th class="smallbold">Value</th>
                    </tr>
                    <tr>
                        <td class="small">user</td>
                        <td class="small">ms Level</td>
                        <td class="small"><xsl:value-of select="@msLevel"/></td>
                    </tr>
                    <tr>
                        <td class="small">user</td>
                        <td class="small">mz Range Start</td>
                        <td class="small"><xsl:value-of select="@mzRangeStart"/></td>
                    </tr>
                    <tr>
                        <td class="small">user</td>
                        <td class="small">mz Range Stop</td>
                        <td class="small"><xsl:value-of select="@mzRangeStop"/></td>
                    </tr>
                    <xsl:apply-templates select="cvParam | userParam"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="precursorList">
        <tr>
            <th class="smallbold" style="{$style.table.th}">
                Precursors<br/>
                (count: <xsl:value-of select="@count"/>)
            </th>
            <td class="small">
                <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
                    <xsl:apply-templates select="precursor"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="precursor">
        <xsl:variable name="specref">
            <xsl:apply-templates select="current()" mode="specref">
                <xsl:with-param name="specid" select="@spectrumRef"/>
            </xsl:apply-templates>
        </xsl:variable>
        <tr>
            <th class="smallbold" style="{$style.table.th}">
                Precursor #<xsl:value-of select="position()"/><br/>
                msLevel: <xsl:value-of select="@msLevel"/><br/>
                <a class="red_boldsmall" href="#{$specref}">
                    Reference spectrum
                </a>
            </th>
            <td class="small">
                <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
                    <xsl:apply-templates select="ionSelection"/>
                    <xsl:apply-templates select="activation"/>
                </table>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="ionSelection">
        <tr>
            <th class="small" style="{$style.table.th}">Ion Selection</th>
            <td class="small">
                <xsl:apply-templates select="current()" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="activation">
        <tr>
            <th class="small" style="{$style.table.th}">Activation</th>
            <td class="small">
                <xsl:apply-templates select="current()" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="comments">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Comments</th>
            <td class="small">
                <xsl:value-of select="."/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="supDesc">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Supplemental Description</th>
            <td class="small">
                <xsl:apply-templates select="supDataDesc"/>
                <xsl:apply-templates select="supSourceFile"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="supDataDesc">
        <xsl:value-of select="@comment"/>
        <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
            <xsl:for-each select="cvParam | userParam">
                <tr>
                    <td class="small"><xsl:apply-templates select="@name"/></td>
                    <td class="small"><xsl:apply-templates select="@value"/></td>
                </tr>
            </xsl:for-each>
        </table>
    </xsl:template>

    <xsl:template match="supSourceFile">
        <span class="smallbold">This supplemental information was generated from this file:</span>
        <table cellpadding="1px" border="1" style="{$style.table}; background-color: #dddddd;">
            <tr>
                <th class="smallbold" style="{$style.table.th}">File name:</th>
                <td class="small"><xsl:value-of select="concat(pathToFile, nameOfFile)"/></td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">File type:</th>
                <td class="small">
                    <xsl:value-of select="fileType"/>
                    <xsl:if test="not(fileType)">&#160;</xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="supDataArrayBinary">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Supplemental Data</th>
            <td class="small">
                There are
                <!-- TODO: check with Richard that this is what's required -->
                <xsl:value-of select="count(../mzArrayBinary/data) + count(../intenArrayBinary/data) + count(data)"/>
                additional data blocks. To retrieve them, please download the
                XML version of this experiment.
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="admin">
        <tr>
            <th class="smallbold" style="{$style.header}">Sample:</th>
            <td class="small_bold" colspan="2">
                <table cellpadding="1px" border="1" style="{$style.table}">
                    <tr>
                        <th class="smallbold" style="{$style.table.th}">Name:</th>
                        <td class="small"><xsl:value-of select="sampleName"/></td>
                    </tr>
                    <tr>
                        <th class="smallbold" style="{$style.table.th}">Description:</th>
                        <td class="small">
                            <xsl:value-of select="sampleDescription/@comment"/>
                            <xsl:if test="not(sampleDescription/@comment)">&#160;</xsl:if>
                        </td>
                    </tr>
                    <xsl:apply-templates select="sampleDescription[cvParam | userParam]"/>
                </table>
            </td>
        </tr>
        <tr>
            <th class="smallbold" style="{$style.header}">Source File:</th>
            <td class="small_bold" colspan="2">
                <xsl:apply-templates select="sourceFile"/>
                <xsl:if test="not(sourceFile)">&#160;</xsl:if>
            </td>
        </tr>
        <tr>
            <th class="smallbold" style="{$style.header}">Contact:</th>
            <td class="small_bold" colspan="2">
                <xsl:apply-templates select="contact"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="sourceFile">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th class="smallbold" style="{$style.table.th}">Name:</th>
                <td class="small"><xsl:value-of select="nameOfFile"/></td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Path:</th>
                <td class="small">
                    <xsl:apply-templates select="pathToFile" mode="textlink"/>
                </td>
            </tr>
            <tr>
                <th class="smallbold" align="left">Type:</th>
                <td class="small">
                    <xsl:value-of select="fileType"/>
                    <xsl:if test="not(fileType)">&#160;</xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="contact">
        <xsl:variable name="style"><xsl:if test="position() mod 2 = 0">background-color:#ffffff</xsl:if></xsl:variable>
        <table cellpadding="1px" border="1" style="{$style.table}; {$style}">
            <tr>
                <th class="smallbold" style="{$style.table.th}">Name:</th>
                <td class="small" width="100%"><xsl:value-of select="name"/></td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Institution:</th>
                <td class="small">
                    <xsl:value-of select="institution"/>
                </td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Contact information:</th>
                <td class="small">
                    <xsl:apply-templates select="contactInfo" mode="textlink"/>
                    <xsl:if test="not(contactInfo)">&#160;</xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="sampleDescription[cvParam | userParam]">
        <tr>
            <th class="smallbold" style="{$style.table.th}">Additional:</th>
            <td class="small">
                <xsl:apply-templates select="current()" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="instrument">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th class="smallbold" style="{$style.table.th}">Name:</th>
                <td class="small"><xsl:value-of select="instrumentName"/></td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Source:</th>
                <td class="small">
                    <xsl:apply-templates select="source" mode="params"/>
                </td>
            </tr>
            <xsl:apply-templates select="analyzerList/analyzer"/>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Detector:</th>
                <td class="small">
                    <xsl:apply-templates select="detector" mode="params"/>
                </td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Additional Information:</th>
                <td class="small">
                    <xsl:apply-templates select="additional" mode="params"/>
                    <xsl:if test="not(additional)">&#160;</xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <xsl:template match="analyzer">
        <tr>
            <th class="smallbold" align="left">Analyzer #<xsl:value-of select="position()"/>:</th>
            <td class="small">
                <xsl:apply-templates select="current()" mode="params"/>
            </td>
        </tr>
    </xsl:template>

    <xsl:template match="dataProcessing">
        <table cellpadding="1px" border="1" style="{$style.table}">
            <tr>
                <th class="smallbold" style="{$style.table.th}">Software Name:</th>
                <td class="small"><xsl:value-of select="software/name"/></td>
            </tr>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Software Version:</th>
                <td class="small"><xsl:value-of select="software/version"/></td>
            </tr>
            <xsl:apply-templates select="analyzerList/analyzer"/>
            <tr>
                <th class="smallbold" style="{$style.table.th}">Comments:</th>
                <td class="small">
                    <xsl:value-of select="software/comment"/>
                    <xsl:if test="not(software/comment)">&#160;</xsl:if>
                </td>
            </tr>
        </table>
    </xsl:template>

    <!-- Ignore all nodes and attributes that do not have an explicit template -->
    <xsl:template match="node() | @*">
        <xsl:apply-templates select="node() | @*"/>
    </xsl:template>

</xsl:stylesheet>
